#!/usr/bin/env python3

import os
import sys

from PyQt6.QtCore import QThread
from PyQt6.QtWidgets import QApplication

from load_controller.gui import GUI
from load_controller.load import Load
from load_controller.profile_handler import ProfileHandler


def main(argv: list[str]) -> int:
    app = QApplication(sys.argv)
    profile_handler = ProfileHandler()
    gui = GUI(profile_handler)
    gui.show()

    load = Load(argv[1], profile_handler)
    load_thread = QThread()
    load.moveToThread(load_thread)
    load_thread.started.connect(load.do_work)
    load_thread.start()

    return app.exec()


if __name__ == "__main__":
    if len(sys.argv) != 3:
        print(f"Usage: {sys.argv[0]} LOAD-PORT BMS-PORT", file=sys.stderr)
        sys.exit(os.EX_USAGE)

    sys.exit(main(sys.argv))
